bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 8. Aventiure
___________________________________________________
| ### DANNEN Gie do Sifrit cer porten vf den sant ### in siner Tarnkappen da er ein schiffel vant ### dar an so stvnt vil tovgen daz Sigemvndes chint ### er fvrt ez balde dannen alsam ez wete der wint ### Den schef meister sach niemen daz schiffel sere vloz ### von Sifrides crepften di waren also groz ### si wanden daz ez fvrte ein svnder starcher wint ### nein ez fvrte Sifrit der schonen Sigelinden chint
###### 482 | ### Bi des tages citen vnt in der einen naht ### chom er ce einem lande mit grozlicher maht ### wol hvndert langer raste vnt dannoch paz ### di hiezen Nibelvnge da er den grozen shaz besaz
###### 483 | ### Der helt der fvr aleine vf einen wert vil [312a] breit ### daz shif gebant vil balde der ritter vil gemeit ### er gie zv einem berge dar vf ein bvrch stvnt ### vnt svchte herberge so di wegemveden tvnt
###### 484 | ### Do chom er fvr di porten verslozzen im div stvnt ### ia hvten si ir eren so noch di livte tvnt ### anz tor begvnde bozen der vnchvnde man ### daz was wol behivtet do vant er innerthalben stan
###### 485 | ### Einen vngefvegen der der bvrge pflach ### bi dem zallen citen sin geweffen lach ### der sprach wer ist der bozet so vaste an daz tor ### do wandelt sine stimme der herre Sifrit da vor
###### 486 | ### Er sprach ich pin ein recke nvo entslivz vf daz tor ### ich erzvorne ir etslichen noch hivte da vor ### der gerne sampfte læge vnt hete sin gemach ### daz mvete den portnære do daz her Sifrit gesprach
###### 487 | ### Nv hete der rise chvene sin gewæffen an getan ### sinen helm vf sin hovbt der vil starche man ### den schilt vil balde <zvhte> daz tor er vf do swief ### wi reht grimmechlichen er an Sifriden lief
###### 488 | ### Wi er getorste wechen so manigen chvenen man ### da wrden slege swinde von siner hant getan ### do begond im shærmen der herliche gast ### do shvf der portnære daz sin gespenge cebrast
###### 489 | ### von einer isen stangen des gie dem helde not ### ein teil begonde fvrhten Sifrit den tot ### do der portnære so crepftechliche slvch ### dar vmbe was im wæge sin herre Sifrit genvch
###### 490 | ### Si striten also sere daz al div bvrch er shal ### do hort man daz diezen in Nibelvnges sal ### er twanch den portnære daz er <in> sit gebant ### div mêre wrden chvnde in al Nibelvnge lant
###### 491 | ### Do hort daz grimme striten verre dvrch den berch ### Albrich der vil chvene ein wildiz getwerch ### er waffende sich balde do lief er da er vant ### disen gast vil edelen da er den risen gebant
###### 492 | ### Albrich was vil grimme starch was er genvch ### helm vnd ringe er an dem libe trvch ### vnt eine geisel swære von golde an siner hant ### do lief er harte snelle da er Sifriden vant
###### 493 | ### Siben chnoffe swære di hiengen vor dar an ### da mit er vmb der hende den schilt dem chvenem man ### slvch so pitterlichen daz im des vil ce brast ### des libes chom in sorge do der wætliche gast
###### 494 | ### Den sherm er vor der hende gar cebrochen swanch [312b] ### do stiez er in di sheiden ein waffen daz was lanch ### den sinen chamerære wold er niht slahen tot ### er shonte siner zvehte als im div tvgent daz gebot
###### 495 | ### Mit starchen sinen handen lief er Albrichen an ### do viench er bi dem parte den altgrisen man ### er zogten vngefvege dæz er lvte schre ### zvht des ivngen heldes div tet Albriche we
###### 496 | ### Lvte rief der chvene lat mich genesen ### vnt moeht ich iemens eigen an einen recken wesen ### dem swre ich des eide ich wær im vndertan ### ich dient iv ê ich stverbe sprach der listige man
###### 497 | ### Er bant ovch Albrichen alsam den risen e ### di Sifrides creffte taten im vil we ### daz getwerch begonde vragen wi sit ir genant ### er sprach ich hæize Sifrit ich <wand> ich wæriv wol bechant
| ### So wol mich dirre mære sprach Albrich daz getwerch ### nv han ich wol er fvnden div degenlichen werch ### daz ir von waren shvlden mvegt landes herre wesen ### ich tvn swaz ir gebietet daz ir mich lazet genesin
###### 499 | ### Do sprach der herre Sifrit ir svlt balde gan ### vnt bringet mir der rechen der besten di <wir> han ### tvsent nibelvnge daz mich di hi gesehen ### warvmbe er do des gerte des hort in niemen ver iehen
###### 500 | ### Dem risen vnt Albriche loset er div bant ### do lief Albrich balde da er di recken vant ### er wachte sorgende der Nibelvnge man ### er sprach wol vf ir helde ir svlt ce Sifride gan
| ### Si sprvngen von den betten vnt waren vil bereit ### tvsent ritter snelle wrden wol gecleit ### si giengen da si fvnden Sifriden stan ### da wart ein shone grvzen ein teil mit werchen getan
###### 502 | ### Vil chercen was en zvendet man shancte im lvter tranch ### daz si shiere chomen er sagts in allen danch ### er sprach ir svlt von hinnen mit mir vber flvt ### des vant er vil bereite di helde chven vnt gvt
###### 503 | ### Wol drizech hvndert recken di waren shiere chomen ### vz den wrden der besten tvsent do genomen ### den brahte man ir helme vnt ander ir gewant ### want er si fveren wolde in daz Prvnnhilde lant
| ### Er sprach ir gvte ritter daz wil ich iv sagen ### ir svlt vil richiv chleider da ce hove tragen ### want vns da sæhen mvezen vil minnechlichiv wip ### dar vmme svlt ir zieren mit [313a] gvter wæte den lip
###### 505 | ### An einen morgen frw hvoben si sich dan ### waz sneller geverten Sifrit do gewan ### si fvrten ros div gvten vnt herlich gewant ### si chomen ritterliche in daz Prvnhilde lant
| ### Do stvenden in den cinnen div minnechlichiv chint ### do sprach div chveneginne weiz iemen wer di sint ### di ich dort sihe vliezen so verre vf dem se ### si fverentsegle riche di sint noch wizer danne der sne
###### 507 | ### Do sprach <der> chvenich von rine ez sint mine man ### di het ich an der verte hi nahen bi ver lan ### di han ich besendet di sint nv vrove chomen ### der herlichen geste wart vil groze war genomen
###### 508 | ### Do sah man Sifride vor in einem shepffe stan ### in herlicher wæte vnde ander manigem man ### do sprach div chveneginne her chvonech ir svlt mir sagen ### sol ich di geste enpfahen oder sol ich grvezen si verdagen
| ### Er sprach ir svlt en gegen in fvor den palas gen ### ob wir si gerne sehen daz si daz wol ver sten ### do tet div chveneginne als ir der chvenich geriet ### Sifride mit dem grvze si von den andern shiet
###### 510 | ### Man shvf in herberge vnt behilt in ir gewant ### do was so vil der geste chomen in daz lant ### daz si sich allenthalben drvngen in der sharn ### do wolden di vil chvenen hæim ce lande varn
###### 511 | ### <· o> sprach div chveneginne ich wold im wesen holt ### der geteiln chvnde min silber vnt min golt ### min vnt des chveneges gesten des ich so vile han ### des antwrte Danchwart des chvnich Giselheres man
###### 512 | ### <Vil> edliv chvneginne lat mich der slvozel pflegen ### ich trwe iz so geteilen sprach der chvene degen ### swaz ich erwerbe shande di lat min eines sin ### daz er milte wære daz tet der degen shin
| ### Do sich hagenen brvder der sluozel vnder want ### so manige gabe riche gap des heldes hant ### swer einer marche gerte dem wart so vil gegeben ### daz di armen alle mvsen vroliche leben
###### 514 | ### Wol bi hvndert pfvnden gap er ane zal ### genvge in richer wæte giengen vor dem sal ### di nie da vor getrvgen so herlichev kleit ### daz gevriesh div chvnegin ez was ir wærliche leit
###### 515 | ### Do sprach div vrowe here her chvenich ich hetes rat ### daz iwer chamerære mir wil der minen wat ### lazen niht beliben er swendet mir min golt ### der iz noch vnder[313b] stvende dem wold ich iemer wesen holt
| ### Er git so riche gabe ia wænet des der degen ### ich habe gesant nach tode ich wils noch lenger pflegen ### ovch trwe iz wol verswenden daz mir <min> vater lie ### so milten chamerære gewan noch chvneginne nie
###### 517 | ### Do sprach von Tronege hagene vrowe iv si geseit ### ez hat <der> chvenech von rine golt vnd kleit ### also vil ce gebene daz wir des haben rat ### daz wir von hinnen fveren iht der Prvnnhilde wat
###### 518 | ### Nein dvrh mine liebe sprach div kvenegin ### lazet <et> mich erfvellen zweinceh leit schrin ### von golde vnt von siden daz geben sol min hant ### so wir chomen veber in daz Gvntheres lant
| ### Mit edelem gesteine ladete man div shrin ### ir selber chamerære da mite mvsen sin ### sine woldes niht getrwen dem Gvntheres man ### Gvnther vnt Hagene dar vmb lachen began
###### 520 | ### Do sprach div chveneginne wem laz ich miniv lant ### div sol ê bestipfften min vnt iwer hant ### do sprach der kvnich edele nv hæizzet her gan ### der iv dar zv gevalle den svl wir voget wesen lan
###### 521 | ### Ein ir hohesten mach div vrowe bi ir sach ### er was ir mvter <bruder> zv dem div vrowe sprach ### nv lat <ev> sin bevolhen mine bverge vnt ovch div lant ### si rihten sich cer verte man sach si riten vf den sant
| ### Si fvrte mit ir dannen sehs vnt ahzech wip ### dar zv wol hvndert mægde vil shone was in der lip ### sin svomten sich niht langer si wolden gahen dan ### di si da heime liezen hey waz der weinen began
###### 523 | ### In tvgentlichen zvehten si rvmte ir eigen lant ### si chvst ir vrivnt di nahen di si bi ir vant ### mit gvtem vrlovbe si chomen vf den se ### zv ir vater lande chom div vrowe nimmer me
| ### Do horte man vf der verte maniger hande spil ### aller chvercewile heten si do vil ### do chom in zv ir reise ein rehter wazzer wint ### si fvren von dem lande mit vil grozen vrevden sint
###### 525 | ### <· one> wolde si den herren niht minnen vf der vart ### ez wart ir kvrcewile vnz in ir hus gespart ### ce Wormz zv der bvorge ceiner hochgezit ### da si vil vrevden riche chomen mit ir helden sit

<<< Übersicht <<< vorige Seite nächste Seite >>>